@include "reset.less";
.vitalstyles-reset {
  font-family: "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", HelveticaNeue, "Helvetica-Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  background-color: #fff;
  padding-left: 30px;
  padding-right: 30px;
}
.vitalstyles-reset.vitalstyles-header {
  background-color: #fafafa;
  padding-top: 70px;
  padding-bottom: 70px;
}
.vitalstyles-reset.vitalstyles-header h1 {
  font-size: 50px;
  color: #333;
  margin: 0;
}
.vitalstyles-reset.vitalstyles-header p {
  font-size: 16px;
  font-weight: bold;
  color: #666;
}
.vitalstyles-reset.vitalstyles-toc {
  padding-top: 40px;
  padding-bottom: 40px;
}
.vitalstyles-reset.vitalstyles-toc h2 {
  margin: 0;
  padding: 0;
  font-size: 18px;
  color: #444;
}
.vitalstyles-reset.vitalstyles-toc ul li {
  margin-top: 10px;
}
.vitalstyles-reset.vitalstyles-toc ul li a {
  color: #666;
  text-decoration: none;
  border-bottom: 1px solid #eee;
  transition-property: border;
  transition-duration: 0.3s;
}
.vitalstyles-reset.vitalstyles-toc ul li a:hover {
  color: #333;
  text-decoration: none;
  border-bottom: 3px solid #ccc;
}
.vitalstyles-reset.vitalstyles-filename-block {
  background-color: #333;
  padding-top: 40px;
  padding-bottom: 40px;
}
.vitalstyles-reset.vitalstyles-filename-block h1 {
  margin: 0;
  padding: 0;
  color: #666666;
}
.vitalstyles-reset.vitalstyles-markdown {
  background-color: #2a2a2a;
  color: #999;
}
.vitalstyles-reset.vitalstyles-markdown h1 {
  margin: 0;
  padding-top: 40px;
  padding-bottom: 16px;
}
.vitalstyles-reset.vitalstyles-markdown p {
  margin: 0;
  padding: 14px 0 14px 0;
}
.vitalstyles-reset.vitalstyles-markdown p + p {
  padding-top: 0;
}
.vitalstyles-reset.vitalstyles-markdown h2,
.vitalstyles-reset.vitalstyles-markdown h3,
.vitalstyles-reset.vitalstyles-markdown h4,
.vitalstyles-reset.vitalstyles-markdown h5,
.vitalstyles-reset.vitalstyles-markdown h6 {
  margin: 0;
  padding: 20px 0 12px 0;
}
.vitalstyles-reset.vitalstyles-markdown h2 + p,
.vitalstyles-reset.vitalstyles-markdown h3 + p,
.vitalstyles-reset.vitalstyles-markdown h4 + p,
.vitalstyles-reset.vitalstyles-markdown h5 + p,
.vitalstyles-reset.vitalstyles-markdown h6 + p {
  padding-top: 0;
}
.vitalstyles-reset.vitalstyles-markdown pre {
  margin: 0;
}
.vitalstyles-example {
  background-color: #2a2a2a;
}
.vitalstyles-example .vitalstyles-example-previewblock {
  background-color: #fff;
}
.vitalstyles-example .vitalstyles-example-codeblock {
  background-color: #2a2a2a;
  padding-left: 30px;
  padding-right: 30px;
  padding-bottom: 10px;
}
.vitalstyles-example .vitalstyles-example-codeblock pre {
  margin: 0;
  padding: 10px 15px;
}
.vitalstyles-example .vitalstyles-example-previewblock-heading,
.vitalstyles-example .vitalstyles-example-codeblock-heading {
  background-color: #2a2a2a;
}
.vitalstyles-example .vitalstyles-example-previewblock-heading h5,
.vitalstyles-example .vitalstyles-example-codeblock-heading h5 {
  font-size: 14px;
  color: #888;
  font-weight: bold;
  padding: 15px 0 4px 0;
  margin: 0;
  text-transform: uppercase;
}
.vitalstyles-example.vitalstyles-example-default .vitalstyles-example-previewblock {
  margin-left: 30px;
  margin-right: 30px;
  padding: 10px 15px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock iframe {
  width: 100%;
  border-width: 0 0 1px 0;
  border-color: #eee;
  border-style: solid;
  margin: 0;
  height: 400px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper {
  padding-bottom: 20px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper a {
  color: #eee;
  background-color: #444;
  border: 1px solid #000;
  border-radius: 3px;
  text-decoration: none;
  padding: 8px 12px;
}
.vitalstyles-example.vitalstyles-example-isolated .vitalstyles-example-previewblock > .vitalstyles-example-isolated-openwrapper a:hover {
  background-color: #000;
  text-decoration: none;
  color: #fff;
}
