<html>
    <head>
        {% block preview_styles %}
            {% if settings.preview_cssfile %}
                <link rel="stylesheet" type="text/css" href="{{ settings.get_preview_cssfilepath_relative_to_outdir() }}">
            {% endif %}
        {% endblock preview_styles %}
    </head>
    <body>
{{ html }}
    </body>
</html>